@@ -5,12 +5,12 @@ import numpy as np
 
 from . import _automethods, backend, binary, ffi, lib, monoid, select, semiring, utils
 from ._ss.matrix import ss
-from .base import BaseExpression, BaseType, call
+from .base import BaseExpression, BaseType, _check_mask, call
 from .dtypes import _INDEX, FP64, lookup_dtype, unify
 from .exceptions import DimensionMismatch, NoValue, check_status
 from .expr import AmbiguousAssignOrExtract, IndexerResolver, Updater
-from .mask import StructuralMask, ValueMask
-from .operator import find_opclass, get_semiring, get_typed_op, op_from_string
+from .mask import Mask, StructuralMask, ValueMask
+from .operator import UNKNOWN_OPCLASS, find_opclass, get_semiring, get_typed_op, op_from_string
 from .scalar import (
     _MATERIALIZE,
     Scalar,
@@ -28,7 +28,7 @@ from .utils import (
     values_to_numpy_buffer,
     wrapdoc,
 )
-from .vector import Vector, VectorExpression, VectorIndexExpr
+from .vector import Vector, VectorExpression, VectorIndexExpr, _select_mask
 
 ffi_new = ffi.new
 
@@ -517,7 +517,7 @@ class Matrix(BaseType):
         )
         op = get_typed_op(op, self.dtype, other.dtype, kind="binary")
         # Per the spec, op may be a semiring, but this is weird, so don't.
-        if require_monoid:
+        if require_monoid:  # pragma: no cover
             if op.opclass != "BinaryOp" or op.monoid is None:
                 self._expect_op(
                     op,
@@ -891,9 +891,40 @@ class Matrix(BaseType):
         Compute SelectOp at each element of the calling Matrix, keeping
         elements which return True.
         """
+        method_name = "select"
         if isinstance(op, str):
             op = select.from_string(op)
-        method_name = "select"
+        else:
+            if isinstance(op, MatrixExpression):
+                # Try to rewrite e.g. `A.select(A == 7)` to `gb.select.value(A == 7)`
+                if thunk is not None:
+                    raise TypeError(
+                        "thunk argument not None when calling select with mask or boolean object"
+                    )
+                expr = select._match_expr(self, op)
+                if expr is not None:
+                    return expr
+                opclass = UNKNOWN_OPCLASS
+            else:
+                op, opclass = find_opclass(op)
+            if opclass == UNKNOWN_OPCLASS:
+                # e.g., `A.select(B.S)` or `A.select(B < 7)`
+                mask = _check_mask(op)
+                if thunk is not None:
+                    raise TypeError(
+                        "thunk argument not None when calling select with mask or boolean object"
+                    )
+                self._expect_type(mask.parent, (Matrix, Mask), within=method_name, argname="op")
+                return MatrixExpression(
+                    "select",
+                    None,
+                    [self, mask, _select_mask, (self, mask)],  # [*expr_args, func, args]
+                    expr_repr="{0.name}.select({1.name})",
+                    nrows=self.nrows,
+                    ncols=self.ncols,
+                    dtype=self.dtype,
+                )
+
         if thunk is None:
             thunk = False  # most basic form of 0 when unifying dtypes
         if type(thunk) is not Scalar:
@@ -1066,7 +1097,7 @@ class Matrix(BaseType):
             "reposition",
             None,
             [self, _reposition, (indices, chunk)],  # [*expr_args, func, args]
-            expr_repr="{2.name}.reposition(%d, %d)" % (row_offset, column_offset),
+            expr_repr="{0.name}.reposition(%d, %d)" % (row_offset, column_offset),
             nrows=nrows,
             ncols=ncols,
             dtype=self.dtype,
@@ -1175,7 +1206,10 @@ class Matrix(BaseType):
         cols = colidx.index
         colscalar = colidx.cscalar
 
-        extra_message = "Literal scalars also accepted."
+        if rowsize is not None or colsize is not None:
+            extra_message = "Literal scalars and lists also accepted."
+        else:
+            extra_message = "Literal scalars also accepted."
 
         value_type = output_type(value)
         if value_type is Vector:
@@ -1344,7 +1378,59 @@ class Matrix(BaseType):
                 dtype = self.dtype if self.dtype._is_udt else None
                 try:
                     value = Scalar.from_value(value, dtype, is_cscalar=None, name="")
-                except TypeError:
+                except (TypeError, ValueError):
+                    if rowsize is not None or colsize is not None:
+                        try:
+                            values, dtype = values_to_numpy_buffer(value, dtype, copy=True)
+                        except Exception:
+                            pass
+                        else:
+                            shape = values.shape
+                            if rowsize is None or colsize is None:
+                                # C[I, j] << [1, 2, 3]
+                                # C[i, J] << [1, 2, 3]
+                                # C(M)[I, j] << [1, 2, 3]
+                                # C(M)[i, J] << [1, 2, 3]
+                                # C[I, j](m) << [1, 2, 3]
+                                # C[i, J](m) << [1, 2, 3]
+                                expected_shape = (rowsize or colsize,)
+                                try:
+                                    vals = Vector.ss.import_full(
+                                        values, dtype=dtype, take_ownership=True
+                                    )
+                                    if dtype.np_type.subdtype is not None:
+                                        shape = vals.shape
+                                except Exception:
+                                    vals = None
+                            else:
+                                # C[I, J] << [[1, 2, 3], [4, 5, 6]]
+                                # C(M)[I, J] << [[1, 2, 3], [4, 5, 6]]
+                                # C[I, J](M) << [[1, 2, 3], [4, 5, 6]]
+                                expected_shape = (rowsize, colsize)
+                                try:
+                                    vals = Matrix.ss.import_fullr(
+                                        values, dtype=dtype, take_ownership=True
+                                    )
+                                    if dtype.np_type.subdtype is not None:
+                                        shape = vals.shape
+                                except Exception:
+                                    vals = None
+                            if vals is None or shape != expected_shape:
+                                if dtype.np_type.subdtype is not None:
+                                    extra = (
+                                        " (this is assigning to a matrix with sub-array dtype "
+                                        f"({dtype}), so array shape should include dtype shape)"
+                                    )
+                                else:
+                                    extra = ""
+                                raise ValueError(
+                                    f"shape mismatch: value array of shape {shape} "
+                                    f"does not match indexing of shape {expected_shape}"
+                                    f"{extra}"
+                                ) from None
+                            return self._prep_for_assign(
+                                resolved_indexes, vals, mask=mask, is_submask=is_submask
+                            )
                     if rowsize is None or colsize is None:
                         types = (Scalar, Vector)
                     else:
