@@ -287,6 +287,8 @@ class Scalar(BaseType):
                 np_type = self.dtype.np_type
                 if np_type.subdtype is None:
                     arr = np.empty(1, dtype=np_type)
+                    if isinstance(val, dict) and np_type.names is not None:
+                        val = _dict_to_record(np_type, val)
                 else:
                     arr = np.empty(np_type.subdtype[1], dtype=np_type.subdtype[0])
                 arr[:] = val
@@ -367,6 +369,10 @@ class Scalar(BaseType):
         if not self._is_cscalar:
             call("GrB_Scalar_wait", [self, _MATERIALIZE])
 
+    def get(self, default=None):
+        """Get the value of a scalar as a Python scalar or the default value if it is empty."""
+        return default if self._is_empty else self.value
+
     @classmethod
     def new(cls, dtype, *, is_cscalar=False, name=None):
         """
@@ -542,6 +548,7 @@ class ScalarExpression(BaseExpression):
     _name_html = wrapdoc(Scalar._name_html)(property(_automethods._name_html))
     _nvals = wrapdoc(Scalar._nvals)(property(_automethods._nvals))
     gb_obj = wrapdoc(Scalar.gb_obj)(property(_automethods.gb_obj))
+    get = wrapdoc(Scalar.get)(property(_automethods.get))
     is_empty = wrapdoc(Scalar.is_empty)(property(_automethods.is_empty))
     isclose = wrapdoc(Scalar.isclose)(property(_automethods.isclose))
     isequal = wrapdoc(Scalar.isequal)(property(_automethods.isequal))
@@ -602,6 +609,7 @@ class ScalarIndexExpr(AmbiguousAssignOrExtract):
     _name_html = wrapdoc(Scalar._name_html)(property(_automethods._name_html))
     _nvals = wrapdoc(Scalar._nvals)(property(_automethods._nvals))
     gb_obj = wrapdoc(Scalar.gb_obj)(property(_automethods.gb_obj))
+    get = wrapdoc(Scalar.get)(property(_automethods.get))
     is_empty = wrapdoc(Scalar.is_empty)(property(_automethods.is_empty))
     isclose = wrapdoc(Scalar.isclose)(property(_automethods.isclose))
     isequal = wrapdoc(Scalar.isequal)(property(_automethods.isequal))
@@ -630,6 +638,18 @@ def _as_scalar(scalar, dtype=None, *, is_cscalar):
         return scalar
 
 
+def _dict_to_record(np_type, d):
+    """Converts e.g. `{"x": 1, "y": 2.3}` to `(1, 2.3)`"""
+    rv = []
+    for name, (dtype, _) in np_type.fields.items():
+        val = d[name]
+        if dtype.names is not None and isinstance(val, dict):
+            rv.append(_dict_to_record(dtype, val))
+        else:
+            rv.append(val)
+    return tuple(rv)
+
+
 _MATERIALIZE = Scalar.from_value(lib.GrB_MATERIALIZE, is_cscalar=True, name="GrB_MATERIALIZE")
 
 utils._output_types[Scalar] = Scalar
