@@ -12,7 +12,7 @@ from graphblas import binary, dtypes, replace
 
 from .conftest import autocompute, compute
 
-from graphblas import Matrix, Scalar, Vector  # isort:skip
+from graphblas import Matrix, Scalar, Vector  # isort:skip (for dask-graphblas)
 
 
 @pytest.fixture
@@ -442,3 +442,19 @@ def test_concat(s):
     A = gb.ss.concat([[s], [s], [empty]])
     expected = Matrix.from_values([0, 1], [0, 0], 5, nrows=3, ncols=1)
     assert A.isequal(expected)
+
+
+def test_record_from_dict():
+    s = Scalar.from_value(
+        {"x": 1, "y": {"a": 2, "b": 3}}, dtype={"x": int, "y": {"a": int, "b": int}}
+    )
+    assert s == (1, (2, 3))
+
+
+def test_get(s):
+    assert s.get() == 5
+    assert s.get("mittens") == 5
+    assert type(compute(s.get())) is int
+    s.clear()
+    assert compute(s.get()) is None
+    assert s.get("mittens") == "mittens"
